@@ -2,12 +2,13 @@ from PyQt5 import QtCore
 from PyQt5.QtCore import QVariant
 import sys
 from packaging import version as version_mod
+
 python_version = f'{str(sys.version_info.major)}.{str(sys.version_info.minor)}'
 if version_mod.parse(python_version) >= version_mod.parse('3.8'):  # from version 3.8 this feature is included in the
     # standard lib
     from importlib import metadata
 else:
-    import importlib_metadata as metadata
+    import importlib_metadata as metadata  # pragma: no cover
 import pkgutil
 
 import traceback
@@ -37,11 +38,13 @@ Cb = 1.602176e-19  # coulomb
 h = 6.626068e-34  # J.s
 c = 2.997924586e8  # m.s-1
 
+
 def get_version():
     with open(str(Path(__file__).parent.parent.joinpath('resources/VERSION')), 'r') as fvers:
         version = fvers.read().strip()
     return version
 
+
 def get_set_local_dir(basename='pymodaq_local'):
     """Defines, creates abd returns a local folder where configurations files will be saved
 
@@ -55,7 +58,7 @@ def get_set_local_dir(basename='pymodaq_local'):
     """
     local_path = Path.home().joinpath(basename)
 
-    if not local_path.is_dir():
+    if not local_path.is_dir():                            # pragma: no cover
         try:
             local_path.mkdir()
         except Exception as e:
@@ -68,14 +71,14 @@ def get_set_local_dir(basename='pymodaq_local'):
     return local_path
 
 
-def copy_preset():
+def copy_preset():                          # pragma: no cover
     path = get_set_preset_path().joinpath('preset_default.xml')
     if not path.exists():  # copy the preset_default from pymodaq folder and create one in pymodad's local folder
         with open(str(Path(__file__).parent.parent.joinpath('resources/preset_default.xml')), 'r') as file:
             path.write_text(file.read())
 
 
-def load_config(config_path=None):
+def load_config(config_path=None):          # pragma: no cover
     if not config_path:
         config_path = get_set_local_dir().joinpath('config.toml')
     config_base = toml.load(Path(__file__).parent.parent.joinpath('resources/config_template.toml'))
@@ -130,7 +133,7 @@ class JsonConverter:
                     return eval(dic['data'])
                 else:
                     return dic
-            else:
+            else:                                               # pragma: no cover
                 return dic
         except Exception:
             return jsonstring
@@ -186,7 +189,7 @@ def Enm2cmrel(E_nm, ref_wavelength=515):
 
     Examples
     --------
-    >>> Enm2cmrel(520, 515)
+    >>> Enm2cmrel(530, 515)
     549.551199853453
     """
     return 1 / (ref_wavelength * 1e-7) - 1 / (E_nm * 1e-7)
@@ -293,10 +296,44 @@ def eV2cm(E_eV):
 
 
 def nm2cm(E_nm):
+    """Converts photon energy from wavelength to absolute cm-1
+
+        Parameters
+        ----------
+        E_nm: float
+              Photon energy in nm
+
+        Returns
+        -------
+        float
+             photon energy in cm-1
+
+        Examples
+        --------
+        >>> nm2cm(0.04)
+        0.000025
+        """
     return 1 / (E_nm * 1e7)
 
 
 def cm2nm(E_cm):
+    """Converts photon energy from absolute cm-1 to wavelength
+
+            Parameters
+            ----------
+            E_cm: float
+                  photon energy in cm-1
+
+            Returns
+            -------
+            float
+                 Photon energy in nm
+
+            Examples
+            --------
+            >>> cm2nm(1e5)
+            100
+            """
     return 1 / (E_cm * 1e-7)
 
 
@@ -418,19 +455,6 @@ def getLineInfo():
         res += t
     return res
 
-    def __repr__(self):
-        if self.axis_seq_indexes == []:
-            return 'Scanner with {:d} positions and shape:({:d}, {:d})'.format(self.Nsteps, len(self.axis_2D_1),
-                                                                               len(self.axis_2D_2))
-        else:
-            shape = ''
-            for ind, axis in enumerate(self.axis_seq):
-                if ind != len(self.axis_seq) - 1:
-                    shape += '{:d}, '.format(len(axis))
-                else:
-                    shape += '{:d}'.format(len(axis))
-            return 'Scanner with {:d} positions and shape:({:s})'.format(self.Nsteps, shape)
-
 
 class ThreadCommand(object):
     """ | Micro class managing the thread commands.
@@ -606,16 +630,6 @@ class DataToExport(Data):
         else:
             raise TypeError('data for the DataToExport class should be a scalar or a ndarray')
 
-        iscorrect = True
-        if data is not None:
-            if not (isinstance(data, np.ndarray) or isinstance(data, float) or isinstance(data, int)):
-                iscorrect = False
-
-        if iscorrect:
-            self['data'] = data
-        else:
-            raise TypeError('data for the DataToExport class should be a scalar or a numpy array')
-
         if dim not in ('Data0D', 'Data1D', 'Data2D', 'DataND') or data is not None:
             if isinstance(data, np.ndarray):
                 ndim = len(data.shape)
@@ -710,9 +724,13 @@ def rint(x):
 
 
 def elt_as_first_element(elt_list, match_word='Mock'):
-    if elt_list != []:
+    if not hasattr(elt_list, '__iter__'):
+        raise TypeError('elt_list must be an iterable')
+    if elt_list:
         ind_elt = 0
         for ind, elt in enumerate(elt_list):
+            if not isinstance(elt, str):
+                raise TypeError('elt_list must be a list of str')
             if match_word in elt:
                 ind_elt = ind
                 break
@@ -726,9 +744,13 @@ def elt_as_first_element(elt_list, match_word='Mock'):
 
 
 def elt_as_first_element_dicts(elt_list, match_word='Mock', key='name'):
-    if elt_list != []:
+    if not hasattr(elt_list, '__iter__'):
+        raise TypeError('elt_list must be an iterable')
+    if elt_list:
         ind_elt = 0
         for ind, elt in enumerate(elt_list):
+            if not isinstance(elt, dict):
+                raise TypeError('elt_list must be a list of dicts')
             if match_word in elt[key]:
                 ind_elt = ind
                 break
@@ -741,7 +763,7 @@ def elt_as_first_element_dicts(elt_list, match_word='Mock', key='name'):
     return plugins
 
 
-def get_plugins(plugin_type='daq_0Dviewer'):
+def get_plugins(plugin_type='daq_0Dviewer'):  # pragma: no cover
     """
     Get plugins names as a list
     Parameters
@@ -776,9 +798,9 @@ def get_plugins(plugin_type='daq_0Dviewer'):
                     else:
                         importlib.import_module(f'{submodule.__package__}.daq_{plugin_type[4:6]}viewer_{mod["name"]}')
                     plugins_import.append(mod)
-                except Exception:
+                except Exception:  # pragma: no cover
                     pass
-        except Exception:
+        except Exception:  # pragma: no cover
             pass
     plugins_import = elt_as_first_element_dicts(plugins_import, match_word='Mock', key='name')
     return plugins_import
@@ -809,7 +831,7 @@ def get_set_config_path(config_name='config'):
     local_path = get_set_local_dir()
     path = local_path.joinpath(config_name)
     if not path.is_dir():
-        path.mkdir()
+        path.mkdir()  # pragma: no cover
     return path
 
 
@@ -818,6 +840,11 @@ def get_set_preset_path():
     """
     return get_set_config_path('preset_configs')
 
+def get_set_batch_path():
+    """ creates and return the config folder path for managers files
+    """
+    return get_set_config_path('batch_configs')
+
 
 def get_set_pid_path():
     """ creates and return the config folder path for PID files
@@ -1085,11 +1112,13 @@ def my_moment(x, y):
     m.extend([np.sqrt(np.sum((x - m[0]) ** 2 * y) * dx / norm)])
     return m
 
+
 def normalize(x):
     x = x - np.min(x)
     x = x / np.max(x)
     return x
 
+
 def odd_even(x):
     """
     odd_even tells if a number is odd (return True) or even (return False)
@@ -1160,7 +1189,7 @@ def linspace_step(start, stop, step):
         The computed distribution axis as an array.
     """
     if np.abs(step) < 1e-12 or np.sign(stop - start) != np.sign(step) or start == stop:
-        raise ValueError('Invalid value for one paramater')
+        raise ValueError('Invalid value for one parameter')
     Nsteps = int(np.ceil((stop - start) / step))
     new_stop = start + (Nsteps - 1) * step
     if np.abs(new_stop + step - stop) < 1e-12:
@@ -1168,6 +1197,7 @@ def linspace_step(start, stop, step):
     new_stop = start + (Nsteps - 1) * step
     return np.linspace(start, new_stop, Nsteps)
 
+
 def find_dict_if_matched_key_val(dict_tmp, key, value):
     """
     check if a key/value pair match in a given dictionnary
@@ -1187,6 +1217,7 @@ def find_dict_if_matched_key_val(dict_tmp, key, value):
             return True
     return False
 
+
 def find_dict_in_list_from_key_val(dicts, key, value, return_index=False):
     """ lookup within a list of dicts. Look for the dict within the list which has the correct key, value pair
 
@@ -1202,15 +1233,16 @@ def find_dict_in_list_from_key_val(dicts, key, value, return_index=False):
     """
     for ind, dict_tmp in enumerate(dicts):
         if find_dict_if_matched_key_val(dict_tmp, key, value):
-                if return_index:
-                    return dict_tmp, ind
-                else:
-                    return dict_tmp
+            if return_index:
+                return dict_tmp, ind
+            else:
+                return dict_tmp
     if return_index:
         return None, -1
     else:
         return None
 
+
 def find_index(x, threshold):
     """
     find_index finds the index ix such that x(ix) is the closest from threshold
@@ -1510,5 +1542,5 @@ if __name__ == '__main__':
     #     print(str(p))
     # v = get_version()
     # pass
-    plugins = get_plugins()
+    plugins = get_plugins()  # pragma: no cover
     pass
