@@ -38,7 +38,7 @@ is_tables = True
 try:
     import tables
     backends_available.append('tables')
-except Exception as e:
+except Exception as e:                              # pragma: no cover
     logger.exception(str(e))
     is_tables = False
 
@@ -47,7 +47,7 @@ is_h5py = True
 try:
     import h5py
     backends_available.append('h5py')
-except Exception as e:
+except Exception as e:                              # pragma: no cover
     logger.exception(str(e))
     is_h5y = False
 
@@ -55,9 +55,8 @@ is_h5pyd = True
 # this one is to be used for remote reading/writing towards a HSDS server (or h5serv), see HDFGroup
 try:
     import h5pyd
-
     backends_available.append('h5pyd')
-except Exception as e:
+except Exception as e:                              # pragma: no cover
     logger.warning(str(e))
     is_h5yd = False
 
@@ -937,8 +936,8 @@ class H5LogHandler(logging.StreamHandler):
         self.h5saver.add_log(msg)
 
 
-class H5Saver(H5Backend, QObject):
-    """QObject containing all methods in order to save datas in a *hdf5 file* with a hierachy compatible with
+class H5SaverBase(H5Backend):
+    """Object containing all methods in order to save datas in a *hdf5 file* with a hierachy compatible with
     the H5Browser. The saving parameters are contained within a **Parameter** object: self.settings that can be displayed
     on a UI using the widget self.settings_tree. At the creation of a new file, a node
     group named **Raw_datas** and represented by the attribute ``raw_group`` is created and set with a metadata attribute:
@@ -973,10 +972,6 @@ class H5Saver(H5Backend, QObject):
 
     Attributes
     ----------
-    status_sig: pyqtSignal
-                emits a signal of type Threadcommand in order to senf log information to a main UI
-    new_file_sig: pyqtSignal
-                  emits a boolean signal to let the program know when the user pressed the new file button on the UI
 
     settings: Parameter
                Parameter instance (pyqtgraph) containing all settings (could be represented using the settings_tree widget)
@@ -985,8 +980,6 @@ class H5Saver(H5Backend, QObject):
                    Widget representing as a Tree structure, all the settings defined in the class preamble variable ``params``
 
     """
-    status_sig = pyqtSignal(utils.ThreadCommand)
-    new_file_sig = pyqtSignal(bool)
 
     params = [
         {'title': 'Save type:', 'name': 'save_type', 'type': 'list', 'values': save_types, 'readonly': True},
@@ -1013,7 +1006,14 @@ class H5Saver(H5Backend, QObject):
         {'title': 'Current scan:', 'name': 'current_scan_name', 'type': 'str', 'value': '', 'readonly': True},
         {'title': 'Current path:', 'name': 'current_scan_path', 'type': 'text',
             'value': config['data_saving']['h5file']['save_path'], 'readonly': True, 'visible': False},
-        {'title': 'h5file:', 'name': 'current_h5_file', 'type': 'text_pb', 'value': '', 'readonly': True},
+        {'title': 'h5file:', 'name': 'current_h5_file', 'type': 'text', 'value': '', 'readonly': True},
+        {'title': 'New file', 'name': 'new_file', 'type': 'action'},
+        {'title': 'Saving dynamic', 'name': 'dynamic', 'type': 'list', 'values': ['uint8', 'int8',
+                                                                                  'uint16', 'int16',
+                                                                                  'uint32', 'int32',
+                                                                                  'uint64', 'int64',
+                                                                                  'float64'],
+         'value': 'float64'},
         {'title': 'Compression options:', 'name': 'compression_options', 'type': 'group', 'children': [
             {'title': 'Compression library:', 'name': 'h5comp_library', 'type': 'list', 'value': 'zlib',
                 'values': ['zlib', 'gzip']},
@@ -1035,8 +1035,6 @@ class H5Saver(H5Backend, QObject):
         https://github.com/HDFGroup/hsds
         """
         H5Backend.__init__(self, backend)
-        QObject.__init__(self)
-
         if save_type not in save_types:
             raise InvalidSave('Invalid saving type')
 
@@ -1052,11 +1050,6 @@ class H5Saver(H5Backend, QObject):
 
         self.settings = Parameter.create(title='Saving settings', name='save_settings', type='group',
                                          children=self.params)
-        self.settings_tree = ParameterTree()
-        self.settings_tree.setMinimumHeight(310)
-        self.settings_tree.setParameters(self.settings, showTop=False)
-        self.settings.child(('current_h5_file')).sigActivated.connect(lambda: self.emit_new_file(True))
-
         self.settings.child(('save_type')).setValue(save_type)
 
         # self.settings.child('saving_options', 'save_independent').show(save_type == 'scan')
@@ -1070,15 +1063,6 @@ class H5Saver(H5Backend, QObject):
     def h5_file(self):
         return self._h5file
 
-    def emit_new_file(self, status):
-        """Emits the new_file_sig
-
-        Parameters
-        ----------
-        status: bool
-                emits True if a new file has been asked by the user pressing the new file button on the UI
-        """
-        self.new_file_sig.emit(status)
 
     def init_file(self, update_h5=False, custom_naming=False, addhoc_file_path=None, metadata=dict([]),
                   raw_group_name='Raw_datas'):
@@ -1125,11 +1109,12 @@ class H5Saver(H5Backend, QObject):
                 self.settings.child(('current_scan_path')).setValue(str(scan_path))
 
                 if not scan_type:
-                    self.h5_file_path = save_path  # will remove the dataset part used for DAQ_scan datas
+                    self.h5_file_path = save_path.parent  # will remove the dataset part used for DAQ_scan datas
                     self.h5_file_name = base_name + datetime_now.strftime('_%Y%m%d_%H_%M_%S.h5')
                 else:
-                    self.h5_file_path = save_path
                     self.h5_file_name = save_path.name + ".h5"
+                    self.h5_file_path = save_path.parent
+
             else:
                 self.h5_file_name = select_file(start_path=base_name, save=True, ext='h5')
                 self.h5_file_path = self.h5_file_name.parent
@@ -1239,10 +1224,10 @@ class H5Saver(H5Backend, QObject):
 
             scan_path, current_filename, dataset_path = self.set_current_scan_path(base_path, base_name, update_h5,
                                                                                    next_scan_index,
-                                                                                   create_dataset_folder=scan_type,
+                                                                                   create_dataset_folder=False,
                                                                                    curr_date=curr_date,
                                                                                    ind_dataset=ind_dataset)
-            self.settings.child(('current_scan_path')).setValue(str(scan_path))
+            self.settings.child(('current_scan_path')).setValue(str(dataset_path))
 
             return scan_path, current_filename, dataset_path
 
@@ -1250,7 +1235,7 @@ class H5Saver(H5Backend, QObject):
             logger.exception(str(e))
 
     @classmethod
-    def find_part_in_path_and_subpath(cls, base_dir, part='', create=False):
+    def find_part_in_path_and_subpath(cls, base_dir, part='', create=False, increment=True):
         """
         Find path from part time.
 
@@ -1280,11 +1265,12 @@ class H5Saver(H5Backend, QObject):
             subfolders_year_name = [x.name for x in base_dir.iterdir() if x.is_dir()]
             subfolders_found_path = [x for x in base_dir.iterdir() if x.is_dir()]
             if part not in subfolders_year_name:
-                if create:
+                if increment:
                     found_path = base_dir.joinpath(part)
-                    found_path.mkdir()
                 else:
                     found_path = base_dir
+                if create:
+                    found_path.mkdir()
             else:
                 ind_path = subfolders_year_name.index(part)
                 found_path = subfolders_found_path[ind_path]
@@ -1318,7 +1304,7 @@ class H5Saver(H5Backend, QObject):
         day_path = cls.find_part_in_path_and_subpath(year_path, part=curr_date.strftime('%Y%m%d'),
                                                      create=True)  # create directory of the day if it doen't exist and return it
         dataset_base_name = curr_date.strftime('Dataset_%Y%m%d')
-        dataset_paths = sorted([path for path in day_path.glob(dataset_base_name + "*") if path.is_dir()])
+        dataset_paths = sorted([path for path in day_path.glob(dataset_base_name + "*"+".h5") if path.is_file()])
 
         if ind_dataset is None:
             if dataset_paths == []:
@@ -1326,13 +1312,13 @@ class H5Saver(H5Backend, QObject):
                 ind_dataset = 0
             else:
                 if update_h5:
-                    ind_dataset = int(dataset_paths[-1].name.partition(dataset_base_name + "_")[2]) + 1
+                    ind_dataset = int(dataset_paths[-1].stem.partition(dataset_base_name + "_")[2]) + 1
                 else:
-                    ind_dataset = int(dataset_paths[-1].name.partition(dataset_base_name + "_")[2])
+                    ind_dataset = int(dataset_paths[-1].stem.partition(dataset_base_name + "_")[2])
 
         dataset_path = cls.find_part_in_path_and_subpath(day_path,
                                                          part=dataset_base_name + "_{:03d}".format(ind_dataset),
-                                                         create=create_dataset_folder)
+                                                         create=False, increment=True)
         scan_paths = sorted([path for path in dataset_path.glob(base_name + '*') if path.is_dir()])
         # if scan_paths==[]:
         #     ind_scan=0
@@ -1342,10 +1328,11 @@ class H5Saver(H5Backend, QObject):
         #     else:
         #         ind_scan=int(scan_paths[-1].name.partition(base_name)[2])+1
         ind_scan = next_scan_index
-
-        scan_path = cls.find_part_in_path_and_subpath(dataset_path, part=base_name + '{:03d}'.format(ind_scan),
-                                                      create=create_scan_folder)
-        return scan_path, base_name + '{:03d}'.format(ind_scan), dataset_path
+        #
+        # scan_path = cls.find_part_in_path_and_subpath(dataset_path, part=base_name + '{:03d}'.format(ind_scan),
+        #                                               create=create_scan_folder)
+        scan_path = ''
+        return dataset_path, base_name + '{:03d}'.format(ind_scan), dataset_path
 
     def get_last_scan(self):
         """Gets the last scan node within the h5_file and under the the **raw_group**
@@ -1567,7 +1554,7 @@ class H5Saver(H5Backend, QObject):
 
         shape, dimension, size = utils.get_data_dimension(data_dict['data'])
         tmp_data_dict = copy.deepcopy(data_dict)
-
+        array_type = getattr(np, self.settings.child('dynamic').value())
         # save axis
         # this loop covers all type of axis : x_axis, y_axis... nav_x_axis, ...
         axis_keys = [k for k in tmp_data_dict.keys() if 'axis' in k]
@@ -1580,14 +1567,15 @@ class H5Saver(H5Backend, QObject):
                 array_to_save = tmp_dict.pop('data')
                 tmp_data_dict.pop(key)
 
-            self.add_array(channel_group, key, 'axis', array_type=np.float, array_to_save=array_to_save,
+            self.add_array(channel_group, key, 'axis', array_type=None, array_to_save=array_to_save,
                            enlargeable=False, data_dimension='1D', metadata=tmp_dict)
 
         array_to_save = tmp_data_dict.pop('data')
         if 'type' in tmp_data_dict:
             tmp_data_dict.pop('type')  # otherwise this metadata would overide mandatory attribute 'type' for a h5 node
         tmp_data_dict.update(metadata)
-        data_array = self.add_array(channel_group, 'Data', 'data', array_type=np.float,
+        array_to_save = array_to_save.astype(array_type)
+        data_array = self.add_array(channel_group, 'Data', 'data', array_type=array_type,
                                     title=title, data_shape=shape, enlargeable=enlargeable, data_dimension=dimension,
                                     scan_type=scan_type, scan_subtype=scan_subtype, scan_shape=scan_shape,
                                     array_to_save=array_to_save,
@@ -1632,7 +1620,7 @@ class H5Saver(H5Backend, QObject):
         """
         if array_type is None:
             if array_to_save is None:
-                array_type = np.float
+                array_type = getattr(np, self.settings.child('dynamic').value())
             else:
                 array_type = array_to_save.dtype
 
@@ -1654,7 +1642,7 @@ class H5Saver(H5Backend, QObject):
                 shape = list(scan_shape[:])
                 shape.extend(data_shape)
                 if init or array_to_save is None:
-                    array_to_save = np.zeros(shape)
+                    array_to_save = np.zeros(shape, dtype=np.dtype(array_type))
 
             array = self.create_carray(where, utils.capitalize(name), obj=array_to_save, title=title)
         self.set_attr(array, 'type', data_type)
@@ -1788,8 +1776,9 @@ class H5Saver(H5Backend, QObject):
                 pass
 
     def update_status(self, status):
-        self.status_sig.emit(utils.ThreadCommand("Update_Status", [status, 'log']))
-        logger.info(status)
+        #self.status_sig.emit(utils.ThreadCommand("Update_Status", [status, 'log']))
+        #logger.info(status)
+        pass
 
     def show_file_content(self):
         form = QtWidgets.QWidget()
@@ -1807,6 +1796,37 @@ class H5Saver(H5Backend, QObject):
         form.show()
 
 
+class H5Saver(H5SaverBase, QObject):
+    """
+    status_sig: pyqtSignal
+                emits a signal of type Threadcommand in order to senf log information to a main UI
+    new_file_sig: pyqtSignal
+                  emits a boolean signal to let the program know when the user pressed the new file button on the UI
+    """
+
+    status_sig = pyqtSignal(utils.ThreadCommand)
+    new_file_sig = pyqtSignal(bool)
+
+    def __init__(self, *args, **kwargs):
+        QObject.__init__(self)
+        H5SaverBase.__init__(self, *args, **kwargs)
+
+        self.settings_tree = ParameterTree()
+        self.settings_tree.setMinimumHeight(310)
+        self.settings_tree.setParameters(self.settings, showTop=False)
+        self.settings.child(('new_file')).sigActivated.connect(lambda: self.emit_new_file(True))
+
+    def emit_new_file(self, status):
+        """Emits the new_file_sig
+
+        Parameters
+        ----------
+        status: bool
+                emits True if a new file has been asked by the user pressing the new file button on the UI
+        """
+        self.new_file_sig.emit(status)
+
+
 def find_scan_node(scan_node):
     """
     utility function to find the parent node of "scan" type, meaning some of its children (DAQ_scan case)
