@@ -169,6 +169,7 @@ class Viewer1D(QtWidgets.QWidget, QObject):
                                   'Switch between normal or XY representation (valid for 2 channels)')
         self.ui.xyplot_action.setCheckable(True)
         button_widget.addAction(self.ui.xyplot_action)
+        self.ui.xyplot_action.setVisible(False)
 
         self.ui.x_label = QAction('x:')
         button_widget.addAction(self.ui.x_label)
@@ -388,6 +389,9 @@ class Viewer1D(QtWidgets.QWidget, QObject):
                         self.roi_manager.settings.child('ROIs', 'ROI_{:02d}'.format(ind), 'use_channel').setValue(
                             self.labels[0])
 
+            self.ui.xyplot_action.setVisible(len(self.labels) == 2)
+
+
         except Exception as e:
             logger.exception(str(e))
 
@@ -588,7 +592,8 @@ class Viewer1D(QtWidgets.QWidget, QObject):
                 self.data_to_export_signal.emit(self.data_to_export)
             else:
                 self.measurement_dict['datas'] = datas
-
+                if self.measurement_dict['x_axis'] is None:
+                    self.measurement_dict['x_axis'] = self._x_axis
                 data_lo = self.math_module.update_math(self.measurement_dict)
                 self.show_math(data_lo)
 
@@ -664,9 +669,9 @@ class Viewer1D_math(QObject):
                 sub_xaxis = self.x_axis[ind1:ind2]
 
                 if self.operations[ind_meas] == "Mean":
-                    data_lo.append(np.mean(sub_data))
+                    data_lo.append(float(np.mean(sub_data)))
                 elif self.operations[ind_meas] == "Sum":
-                    data_lo.append(np.sum(sub_data))
+                    data_lo.append(float(np.sum(sub_data)))
                 elif self.operations[ind_meas] == 'half-life' or self.operations[ind_meas] == 'expotime':
                     ind_x0 = utils.find_index(sub_data, np.max(sub_data))[0][0]
                     x0 = sub_xaxis[ind_x0]
