@@ -12,6 +12,7 @@ import numpy as np
 
 import pymodaq.daq_utils.parameter.ioxml
 import pymodaq.daq_utils.parameter.utils
+import pymodaq.daq_utils.parameter.pymodaq_ptypes
 from pymodaq.daq_utils.daq_utils import getLineInfo, ThreadCommand, load_config
 from pyqtgraph.parametertree import Parameter
 from collections import OrderedDict
@@ -496,7 +497,7 @@ class TCPClient(QObject):
                         self.cmd_signal.emit(ThreadCommand('Update_Status', [getLineInfo() + str(e), 'log']))
                         self.socket.send_string('Quit')
                         self.socket.close()
-                    except Exception:
+                    except Exception:  # pragma: no cover
                         pass
                     finally:
                         break
@@ -817,7 +818,7 @@ class TCPServer(QObject):
             self.command_done(command_sock)
 
         elif command == "Infos":
-            """replace entirely the client settings information onthe server widget
+            """replace entirely the client settings information on the server widget
             should be done as the init of the client module"""
             try:
                 sock = self.find_socket_within_connected_clients(self.client_type)
@@ -897,7 +898,7 @@ class MockServer(TCPServer):
         self.settings = Parameter.create(name='settings', type='group', children=tcp_parameters)
 
 
-if __name__ == '__main__':
+if __name__ == '__main__':  # pragma: no cover
     import sys
 
     app = QtWidgets.QApplication(sys.argv)
